#!/usr/bin/python
#
# Assign a bug task to a team, tag it rls-p-tracking and set the milestone to
# ubuntu-12.04
#
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2011 Canonical, Ltd.
# License: GPLv3

import lpl_common
import optparse
import sys


def task_to_modify(bug_tasks, package):
    task_to_modify = None
    for task in bug_tasks:
        if 'precise' in str(task) and package in str(task):
            task_to_modify = task
        elif package in str(task) and not task_to_modify:
            task_to_modify = task
    return task_to_modify


if __name__ == '__main__':

    OPEN_STATUS = ['New', 'Incomplete', 'Confirmed', 'Triaged', 'In Progress',
        'Fix Committed']
    CLOSED_STATUS = ['''Won't Fix''', 'Fix Released', 'Invalid', 'Expired',
        'Opinion']
    ALL_STATUS = OPEN_STATUS + CLOSED_STATUS

    lp = lpl_common.connect(version='devel')

    ubuntu = lp.distributions['ubuntu']

    parser = optparse.OptionParser(usage="usage: %prog --assignee LPUSER\
            --milestone MILESTONE --bug BUG_NUMBER")

    parser.add_option('--assignee', help='Launchpad user to assign the task')
    parser.add_option('--milestone', help='Milestone to assign the task - defaults to ubuntu-12.04')
    parser.add_option('--package', help='Source package bug task to modify')
    parser.add_option('--bug', help='Bug number to modify', type=int)

    (opt, args) = parser.parse_args()

    bug = lp.bugs[opt.bug]

    if opt.assignee:
        try:
            assignee = lp.people[opt.assignee]
        except KeyError:
            print 'Unable to find Launchpad user named %s' % opt.assignee
            sys.exit(1)
    else:
        assignee = None

    if opt.milestone is None:
        milestone = ubuntu.getMilestone(name='ubuntu-12.04')
    else:
        milestone = ubuntu.getMilestone(name=opt.milestone)

    if opt.package:
        package = opt.package

    src_pkgs = [task.bug_target_name.split(' ')[0] for task in bug.bug_tasks]

    if len(set(src_pkgs)) > 1 and not opt.package:
        print 'LP: #%s has multiple source package tasks so you must specify --package' % bug.id
        sys.exit(1)
    elif len(set(src_pkgs)) == 1 and not opt.package:
        package = src_pkgs[0]

    task = task_to_modify(bug.bug_tasks, package)

    if task is None and opt.package:
        print "LP: #%s does not have a %s task" % (bug.id, opt.package)
        sys.exit(1)

    if task.status in CLOSED_STATUS:
        print "LP: #%s does not have an open bug task about %s" % (bug.id,
            opt.package)
        sys.exit(1)

    target = task.bug_target_name
    task.milestone = milestone
    task.lp_save()
    if assignee:
        task.assignee = assignee
        task.lp_save()
    tags = bug.tags
    if 'rls-p-tracking' not in tags:
        tags.append('rls-p-tracking')
        bug.tags = tags
        bug.lp_save()

    print 'LP: #%s task regarding %s was modified' % (bug.id, target)
