#!/usr/bin/env python
#
# 2010-02-08
# Approve an applicant's membership in the Ubuntu Bug Squad team

from launchpadlib.errors import HTTPError
from datetime import date

import lpl_common

import sys

lp = lpl_common.connect(version='devel')

welcome = "Thanks for helping to make Ubuntu even better and welcome to the "\
          "team! Please be familiar with the Triage Guide at "\
          "https://wiki.ubuntu.com/Bugs/HowToTriage/.  If you have any "\
          "questions about bug triage at all please ask in #ubuntu-bugs on "\
          "irc.freenode.net.  If you don't get an answer quickly please "\
          "email the Bug Squad at ubuntu-bugsquad@lists.ubuntu.com."

# 2010-06-30 - the declined text must be adjusted if we change the rules of
# engagement
declined = "Thank you for your interest in helping bug triaging and making "\
           "Ubuntu better. We cannot approve your membership right now, "\
           "since you did not complete all required steps (please see "\
           "https://wiki.ubuntu.com/BugSquad). We have listed the basic "\
           "requirements below:\n\n  * sign the Ubuntu Code of Conduct.\n"\
           "  * Read the Triage Guide.\n  * Subscribe to the Bug Squad "\
           "Mailing List.\n\nAfter you complete the above steps, please "\
           "reapply for membership on the BugSquad team at Launchpad, and "\
           "we will then approve your request.\n\nAgain, thank you."

lpid = sys.argv[1]

try:
    person = lp.people['%s' % lpid]
except HTTPError, error:
    print "Could not find and exact match for person %s" % lpid
    sys.exit(1)

team = lp.people['bugsquad']

today = date.today()

future = today.replace(year = today.year + 1)

expiration_date = future.strftime("%Y-%m-%d")

# 2010-04-05 - member_detail is 404'ing now for non-proposed members?
member_detail = None
try:
    member_detail = lp.load(str(lp._root_uri) + '~bugsquad/+member/%s' % lpid)
except HTTPError, error:
    if error.response['status'] != '404':
        print "unexpected HTTP error, stopping"
        print error.content
        sys.exit(1)
    else:
        print error.response, error.content

if person.is_ubuntu_coc_signer:
    if member_detail is not None:
        if member_detail.status == 'Approved':
            try:
                member_detail.setExpirationDate(date=expiration_date)
                print "%s: %s was already a member, expiration set to %s." %\
                      (lpid, person.display_name, expiration_date)
            except HTTPError, error:
                print state, error.content
        else:
            try:
                team.addMember(person=person, status='Approved',
                               comment=welcome)
                print "%s: %s has been added." % (lpid, person.display_name)
            except HTTPError, error:
                print state, error.content
    # this will handle any other status -- including non-proposed persons
    else:
        try:
            team.addMember(person=person, status='Approved', comment=welcome)
            print "%s: %s has been added." % (lpid, person.display_name)
        except HTTPError, error:
            print state, error.content
else:
    # CoC not signed
    print "%s: %s has not signed the CoC; declining request." % \
          (lpid, person.display_name)
    if member_detail.status == 'Proposed':
        try:
            member_detail.setStatus(status="Declined", comment=declined)
        except HTTPError, error:
            print state, error.content
