#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2009-2010 Canonical, Ltd.
# License: GPLv3
#
# Forward an Ubuntu bug report from Launchpad using the bug's description as a
# starting point to the Debian bug tracking system using reportbug.

import lpl_common, optparse, subprocess, sys, os
from tempfile import mkstemp

def submit_bugreport(subject, body, devel_name, version, package):
    cmd = ["reportbug",
           "-B", "debian",
           "-s", subject,
           "--include", body,
           "-P", "User: ubuntu-devel@lists.ubuntu.com",
           "-P", "Usertags: origin-ubuntu %s" % devel_name,
           "--paranoid",
           "--check-available",
           "--package-version", version, package]
    if os.getenv('DEBUG'):
	    print "%s\n" % cmd
    if subprocess.call(cmd) == 0:
        return True
    else:
        return False

def get_current_package_version(src_pkg_name):
    for archive in ubuntu.archives:
        if archive.name == 'primary':
            primary = archive

    devel = ubuntu.current_series
    devel_name = devel.name

    pub_sources = primary.getPublishedSources(source_name=src_pkg_name,
                                              status="Published",
                                              pocket="Release",
                                              distro_series=devel,
                                              exact_match=True)

    # collection size is not available for this in lucid
    if int(pub_sources._wadl_resource.representation['total_size'])> 1:
        print >> sys.stderr, ("There is somehow more than one source package "
                              "available.  Aborting.")
        sys.exit(1)

    # TODO - strip out build out of the source_package_version
    src_pkg_version = pub_sources[0].source_package_version
    return src_pkg_version, devel_name

def create_email_body(bug):
    bug_body = ("This bug report was also filed in Ubuntu and can be found at\n"
                "http://launchpad.net/bugs/%s\nThe description, from %s, follows:"
                % (bug.id, bug.owner.display_name))
    bug_body += "\n\n%s\n" % bug.description

    fd, body = mkstemp(prefix="forwarded-from-ubuntu-", suffix=".txt")
    fp = os.fdopen(fd, 'w')
    fp.write(bug_body.strip())
    fp.close()
    return body

if __name__ == '__main__':

    lp = lpl_common.connect()
    ubuntu = lp.distributions['ubuntu']

    parser = optparse.OptionParser()
    parser.add_option("-b", "--bug", help="Bug number", metavar="BUG")
    parser.add_option("-u", "--ubuntu",
                      help="Report bug even though there are Ubuntu changes to the package",
                      action="store_true")
    parser.add_option("-F", "--force",
                      help="Forward even if there is more than one bug task",
                      action="store_true")

    (opt, args) = parser.parse_args()

    if not os.path.exists('/usr/bin/reportbug'):
    	print >> sys.stderr ("This utility requires the «reportbug» package, "
                             "which isn't currently installed.")
    	sys.exit(1)

    if opt.bug:
        bug = lp.bugs[opt.bug]
    elif not opt.bug:
        print >> sys.stderr, ("A bug number (-b) is required for forwarding.")
        sys.exit(1)

    if not opt.force:
        # only do something if the bug has one bug task
        if len(bug.bug_tasks) != 1:
            print >> sys.stderr, ("Bug has more than one task.  Aborting.")
            sys.exit(1)
        task = bug.bug_tasks[0]
    elif opt.force:
        # TODO - needs to handle more situations like a bug with 2 Ubuntu bug
        # tasks
        for bug_task in bug.bug_tasks:
            if 'Ubuntu' in bug_task.bug_target_name:
                task = bug_task

    if task.status not in ['Confirmed', 'Triaged', 'In Progress']:
        print >> sys.stderr, ("Before forwarding a bug to Debian its status "
                              "should be either Confirmed, Triaged or In "
                              "Progress. Aborting.\n")
        sys.exit(1)

    src_pkg_name = task.bug_target_name.split(' ')[0]

    version, devel_name = get_current_package_version(src_pkg_name)

    if 'ubuntu' in version and not opt.ubuntu:
        print >> sys.stderr, ("The package %s may carry Ubuntu changes and "
                              "the bug will not be forwarded to Debian." %
                              src_pkg_name)
        sys.exit(1)

    body = create_email_body(bug)
    submitted = submit_bugreport(bug.title, body, devel_name, version, src_pkg_name)
    if submitted:
        os.unlink(body)
        print ("After you've received a Debian bug number please link the "
               "Launchpad bug report to the Debian one.  For further details "
               "see https://wiki.ubuntu.com/Bugs/Watches.\n")
