#!/usr/bin/python
#
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2011 Canonical, Ltd.
# License: GPLv3

import lpl_common
import optparse

OPEN_STATUSES = ['New', 'Incomplete', 'Confirmed', 'Triaged', 'In Progress',
    'Fix Committed']

lp = lpl_common.connect(use_edge=False, version='devel')

ubuntu = lp.distributions['ubuntu']

parser = optparse.OptionParser(usage="usage: %prog --package PACKAGE")

parser.add_option('--package', help='Ubuntu source package name')

(opt, args) = parser.parse_args()

if not opt.package:
    parser.error('Package name required')

pkg_name = opt.package

pkg = ubuntu.getSourcePackage(name=pkg_name)

for task in pkg.searchTasks(status='Fix Released'):
    fbug = task.bug
    bug_numbers = []
    for bug in task.findSimilarBugs():
        if bug.id == fbug.id:
            continue
        for task in bug.bug_tasks:
            if task.status in OPEN_STATUSES:
                bug_numbers.append(task.bug.id)
    if len(bug_numbers) == 0:
        continue
    print "Similar bugs about LP: #%s - %s" % (fbug.id, fbug.title)
    bug_numbers.sort(reverse=True)
    for number in bug_numbers:
        bug = lp.bugs[number]
        print "  LP: #%s - %s" % (number, bug.title)
