#!/usr/bin/env python
#
# Copyright 2009 Canonical, Ltd
# Author: Brian Murray <brian@ubuntu.com>
# License: GPLv3
# 
# 2010-06-23
# 
# Given a bug number with a patch check to see that the bug is not already in
# the patching processing queue and if it isn't modify it by tagging the bug
# patch and subscribing the right people and or teams to the bug report.

from launchpadlib.launchpad import Launchpad
from launchpadlib.uris import LPNET_SERVICE_ROOT, STAGING_SERVICE_ROOT
from launchpadlib.errors import HTTPError
from launchpadlib.credentials import Credentials

import os, sys

cachedir = os.path.expanduser("~/.launchpadlib/cache/")

if not os.path.exists(cachedir):
    os.makedirs(cachedir,0700)

script_name = sys.argv[0].split("/")[-1].split('.')[0]

credfile = os.path.expanduser('~/.launchpadlib/%s.cred' % script_name)

try:
    credentials = Credentials()
    credentials.load(open(credfile))
    launchpad = Launchpad(credentials, LPNET_SERVICE_ROOT, cachedir)
except:
    launchpad = Launchpad.get_token_and_login(script_name, LPNET_SERVICE_ROOT, cachedir)
    launchpad.credentials.save(open(credfile,"w",0600))

def save_entry(entry):
    try:
        entry.lp_save()
    except HTTPError, error:
        print error.content

def tag_it(bug):
    bug = launchpad.bugs[bug.id]# fresh bug object, LP: #336866 workaround
    bug.tags = bug.tags + ['patch']# LP: #254901 workaround
    save_entry(bug)

# commonly used things
ubuntu = launchpad.distributions['ubuntu']

bug_number = sys.argv[1]

# teams to subscribe
reviewers = launchpad.people['ubuntu-reviewers']
jfo = launchpad.people['jeremyfoshee']

# teams that process bugs with patches
workflow_teams = [ 'ubuntu-universe-sponsors', 'ubuntu-main-sponsors', 'ubuntu-sru', \
                   'ubuntu-mir', 'ubuntu-release', 'ubuntu-reviewers', 'motu-sru', \
                   'ubuntu-security-sponsors', 'ubuntu-sponsors' ]

# tags that indicate a review has happened
reviewed_tags = [ 'patch-needswork', 'patch-forwarded-upstream', 'patch-forwarded-debian', \
                  'indicator-application', 'patch-accepted-upstream', 'patch-accepted-debian', \
                  'patch-rejected-upstream', 'patch-rejected-debian', 'patch-rejected']

# kernel packages are special and have a specific person to subscribe
kernel_packages = ['linux (Ubuntu)', 'linux-fsl-imx51 (Ubuntu)', 'ubuntu-imx (Ubuntu)', \
                   'linux-backports-modules-2.6.32 (Ubuntu)', 'linux-ti-omap (Ubuntu)']

# skip these packages altogether
skipped_packages = ['ubuntu-docs (Ubuntu)', 'xserver-xorg-video-openchrome (Ubuntu)']

bug = launchpad.bugs[bug_number]
subscribers = [ subscriber.person.name for subscriber in bug.subscriptions ]
task_targets = [ task.bug_target_name for task in bug.bug_tasks ]

if bug.latest_patch_uploaded is None:
    sys.stderr.write("Has no patch so skipping LP: #%s\n" % bug.id )
    sys.exit(1)

# these bugs have been reviewed and require something
elif set(reviewed_tags).intersection(bug.tags):
    sys.stderr.write("Reviewed tag found so skipping LP: #%s\n" % bug.id )
    sys.exit(1)

# don't act on sync requests with the archive admin team subscribed
elif 'sync' in bug.title.lower() and 'ubuntu-archive' in subscribers:
    sys.stderr.write("Likely sync request found so skipping LP: #%s\n" % bug.id )
    sys.exit(1)

# don't act on bugs that already have a sponsor's team subscribed
elif set(workflow_teams).intersection(subscribers):
    sys.stderr.write("A sponsor team is already subscribed to LP: #%s\n" %  bug.id )
    sys.exit(1)

# subscribe the team and add the tag patch to the bug report
# the kernel's workflow is special just subscribe jfo
elif set(kernel_packages).intersection(task_targets): #task.bug_target_name in kernel_packages:
    bug.subscribe(person=jfo)
    if 'patch' not in bug.tags:
        tag_it(bug)

elif set(skipped_packages).intersection(task_targets):
    sys.stderr.write("Black listed package so skipping LP: #%s\n" % bug.id )
    sys.exit(1)

else:
    bug.subscribe(person=reviewers)
    if 'patch' not in bug.tags:
        tag_it(bug)
