#!/usr/bin/python
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2010 Canonical, Ltd.
# License: GPLv3
#
# Tell me which packages are getting bugs reported about them

from operator import itemgetter

import datetime
import lpl_common
import optparse


def process_tasks(recent_tasks):
    packages = {}
    for task in recent_tasks:
        src_pkg = task.bug_target_name.split(' ')[0]
        if src_pkg == 'ubuntu':
            continue
        packages[src_pkg] = packages.setdefault(src_pkg, 0) + 1
    return packages

if __name__ == '__main__':
    lp = lpl_common.connect(version='devel')
    ubuntu = lp.distributions['ubuntu']

    parser = optparse.OptionParser()
    parser.add_option("--within", help="Filter on bugs reported within \
                                        X day(s)")
    parser.add_option("--limit", help="Number of packages to return")

    (opt, args) = parser.parse_args()

    today = datetime.datetime.utcnow()
    target_date = today - datetime.timedelta(int(opt.within))

    recent_tasks = ubuntu.searchTasks(created_since=target_date)

    freq = process_tasks(recent_tasks)

    if opt.limit:
        limit = int(opt.limit)
    else:
        limit = len(freq)

    for k,v in sorted(freq.items(), key=itemgetter(1), reverse=True)[:limit]:
        print "%s: %s" % (k, v)
