#!/usr/bin/python
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2010 Canonical, Ltd.
# License: GPLv3
#
# Find bug reports that nominated for the development release of Ubuntu
# Returns only unique bug ids and can filter on the date the nomination was
# created

import lpl_common
import optparse

from datetime import datetime, date
from operator import itemgetter


def find_nominations(release):
    nominated_tasks = [task for task in \
                       ubuntu.searchTasks(nominated_for=release)]

    nominations = {}
    for task in nominated_tasks:
        nomination = task.bug.getNominationFor(target=release)
        if str(nomination) not in str(nominations):
            nom_date = nomination.date_created.date()
            if nom_date > begin and nom_date < end:
                nominations[nomination] = nom_date

    for k, v in sorted(nominations.iteritems(), key=itemgetter(1)):
        print 'LP: #%s, %s, %s' % (k.bug.id, v, k.owner.name)

if __name__ == '__main__':
    lp = lpl_common.connect()

    ubuntu = lp.distributions['ubuntu']

    parser = optparse.OptionParser()
    parser.add_option("--since", help="Starting date %Y-%m-%d")
    parser.add_option("--before", help="Ending date %Y-%m-%d")
    parser.add_option("--release", help="Release for which to find \
                                         nominations")

    (opt, args) = parser.parse_args()

    if opt.release is None:
        release = ubuntu.current_series
    else:
        release = ubuntu.getSeries(name_or_version=opt.release)
    #for series in ubuntu.getDevelopmentSeries():
    #    if series.active:
    #        dev_release = series

    if opt.since:
        begin = datetime.strptime(opt.since, "%Y-%m-%d").date()
    else:
        begin = date(2001, 01, 01)

    if opt.before:
        end = datetime.strptime(opt.before, "%Y-%m-%d").date()
    else:
        end = date.today()

    find_nominations(release)
