#!/usr/bin/python
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2011 Canonical, Ltd.
# License: GPLv3

import lpl_common
import optparse
import sys

PKGTEAMS = [
        'checkbox-bugs',
        'desktop-packages',
        'documentation-packages',
        'dx-packages',
        'edubuntu-bugs',
        'foundations-bugs',
        'kernel-packages',
        'kubuntu-bugs',
        'lubuntu-packaging',
        'translators-packages',
        'ubuntu-apps-bugs',
        'ubuntu-phonedations-bugs',
        'ubuntu-sdk-bugs',
        'ubuntu-security-bugs',
        'ubuntu-server',
        'ubuntu-webapps-bugs',
        'ubuntuone-hackers',
        'unity-api-bugs',
        'unity-ui-bugs',
        'xubuntu-bugs',
       ]

lp = lpl_common.connect(use_edge=False, version='devel')

parser = optparse.OptionParser(usage="usage: %prog --user LPUSER \ --package SRCPKG,SRCPKG")

parser.add_option('-u', '--user', help='team or person to subscribe')
parser.add_option('-p', '--package', help='Ubuntu source package(s), comma separated, for subscription')

(opt, args) = parser.parse_args()

packages = opt.package.split(',')

try:
    lpuser = lp.people[opt.user]
except KeyError:
    print('Unable to find a Launchpad user named %s.' % opt.user)
    sys.exit(1)

if lpuser.is_team:
    if lpuser.name not in PKGTEAMS:
        print('%s is not a package team.' % lpuser.name)
        sys.exit(1)

ubuntu = lp.distributions['ubuntu']

# This takes a long time so its disabled, plus you can't be subscribed 2x.
#subscriptions = [p.name for p in lpuser.getBugSubscriberPackages()]

for package in packages:
    # if package in subscriptions:
    #     print("%s is already subscribed to all bugs about %s" % (opt.user,
    #         package))
    #     continue
    srcpkg = ubuntu.getSourcePackage(name=package)
    srcpkg.addBugSubscription(subscriber=lpuser)
    print('%s is now subscribed to all bugs about %s.' % (opt.user, package))
