#!/usr/bin/python
# -*- coding: utf-8 -*-
# Bugday script, simple script to create the bug day list.
# in order to make it work you need to pass the source package name as an
# argument to the script as in:
# ./ubuntu-bugday.py --package rhythmbox
# the script will create a txt file with the bug lists,
# the name of the file is the name of the target: rhythmbox.txt

import optparse
import sys

from datetime import datetime, date

import lpl_common


def create_bugday_wiki(target, since, quantity):
    datafile = open('%s.txt' % target.name, 'w')

    tasks = target.searchTasks(status='New', order_by='-datecreated',
        created_since=since)
    datafile.write(("###### NEW BUGS: %s ######\n" % len(tasks)))

    for task in tasks[:quantity]:
        bug_num = task.bug.id
        line = "||<rowstyle=\"background-color: ;\"> [[https://launchpad.net/bugs/%s|%s ]] || %s ||  ||\n" % (bug_num, bug_num, task.bug.title.encode('utf-8'))
        datafile.write(line)

    tasks = target.searchTasks(status='Confirmed', order_by='-datecreated',
        created_since=since)
    datafile.write(("\n###### CONFIRMED BUGS: %s ######\n" % len(tasks)))
    for task in tasks[:quantity]:
        bug_num = task.bug.id
        line = "||<rowstyle=\"background-color: ;\"> [[https://launchpad.net/bugs/%s|%s ]] || %s ||  ||\n" % (bug_num, bug_num, task.bug.title.encode('utf-8'))
        datafile.write(line)

    tasks = target.searchTasks(status='Incomplete (with response)',
        order_by='-datecreated', created_since=since)
    datafile.write(("\n###### INCOMPLETE BUGS: %s ######\n" % len(tasks)))
    for task in tasks[:quantity]:
        bug_num = task.bug.id
        line = "||<rowstyle=\"background-color: ;\"> [[https://launchpad.net/bugs/%s|%s ]] || %s ||  ||\n" % (bug_num, bug_num, task.bug.title.encode('utf-8'))
        datafile.write(line)


    tasks = target.searchTasks(status_upstream='pending_bugwatch',
        order_by='-datecreated')
    datafile.write(("\n###### BUGS TO SEND UPSTREAM: %s ######\n" % len(tasks)))
    for task in tasks[:quantity]:
        bug_num = task.bug.id
        line = "||<rowstyle=\"background-color: ;\"> [[https://launchpad.net/bugs/%s|%s ]] || %s ||  ||\n" % (bug_num, bug_num, task.bug.title.encode('utf-8'))
        datafile.write(line)

    tasks = target.searchTasks(has_patch=True, order_by='-datecreated')
    datafile.write(("\n###### BUGS WITH A PATCH: %s ######\n" % len(tasks)))
    for task in tasks[:quantity]:
        bug_num = task.bug.id
        line = "||<rowstyle=\"background-color: ;\"> [[https://launchpad.net/bugs/%s|%s ]] || %s ||  ||\n" % (bug_num, bug_num, task.bug.title.encode('utf-8'))
        datafile.write(line)

    datafile.close()


if __name__ == '__main__':
    launchpad = lpl_common.connect()
    ubuntu = launchpad.distributions["ubuntu"]

    parser = optparse.OptionParser()
    parser.add_option("--package", help="Package to have a hug day for")
    parser.add_option("--since", help="Look for bug tasks created since %Y-%m-%d")
    parser.add_option("--limit", help="Number of rows per type to return " \
        "default of 50")

    (opt, args) = parser.parse_args()

    if opt.since:
        begin = datetime.strptime(opt.since, "%Y-%m-%d")
    else:
        begin = date(2001, 01, 01)

    if not opt.limit:
        limit = 50
    else:
        limit = int(opt.limit)

    if not opt.package:
        print ('A package is required.')
        sys.exit(1)
    else:
        package = opt.package

    target = ubuntu.getSourcePackage(name=package)
    if target is None:
        print 'Source package %s not found for Ubuntu' % package
        sys.exit(1)

    create_bugday_wiki(target, begin, limit)
