#!/usr/bin/python
# Author: Brian Murray <brian@canonical.com>
# Copyright (C) 2010 Canonical, Ltd.
# License: GPLv3
#
# Tell me which packages are getting bugs reported about them
# 2011-04-15 - It'd be neat if there was information about the types of bugs -
#   counts of apport-crash, apport-package etc...

from operator import itemgetter
from qadashboard_utils import *
from sys import argv

import datetime
import lpl_common
import numpy


def process_tasks(recent_tasks):
    packages = {}
    for task in recent_tasks:
        src_pkg = task.bug_target_name.split(' ')[0]
        if src_pkg == 'ubuntu':
            continue
        packages[src_pkg] = packages.setdefault(src_pkg, 0) + 1
    return packages

if __name__ == '__main__':
    lp = lpl_common.connect(version='devel')
    ubuntu = lp.distributions['ubuntu']
    days = argv[1]

    today = datetime.datetime.utcnow()
    target_date = today - datetime.timedelta(int(days))

    recent_tasks = ubuntu.searchTasks(created_since=target_date)

    freq = process_tasks(recent_tasks)
    mean = int(round(numpy.mean(freq.values())))

    # Setup for writing to the data file
    if days == '1':
        metric = "Top 5 Packages With New Bugs Over the Last Day"
    else:
        metric = "Top 5 Packages With New Bugs Over the Last %s Days" % days
    metric += "<br>(Mean of %i)" % mean
    data = ""
    rows = 5
    string_output = ""

    for package, quantity in sorted(freq.items(), key=itemgetter(1), reverse=True)[:rows]:
        url = "https://bugs.launchpad.net/ubuntu/+source/%s/+bugs?field.searchtext=&orderby=-datecreated&search=Search&field.status:list=NEW" % package
        data += "color=\"%s\" url=\"%s\" status=\"%s: %i\"\n" % ("", url, package, quantity)

    data = "top_5_packages_with_new_bugs_over_%s: metric=\"%s\" rows=\"%d\" " % (days, metric, rows) + data
    data_file = DATA_DIR + "packages_with_most_new_bugs_over_%s.txt" % days
    create_file(data_file, data)
