#!/usr/bin/python
# This script creates the data to be used for reporting on
# the automated mago tests in a Unity environment.
# It is based on the ubuntu weatherreport from Leann Ogasawara.
#
# Copyright 2010  Canonical, Ltd.
# Author: Marjo Mercado <marjo.mercado@canonical.com>
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
# the full text of the license.

from qadashboard_utils import *

def mago_unity_tests():
    # Setup for writing to the data file
    metric = "Automated Unity Desktop on Natty Test Results"
    data = ""
    rows = 0

    test_results_urls = ["http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/gcalctool/gcalctool_calculations.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/gcalctool/gcalctool_options.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/gcalctool/gcalctool_views.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/gedit/gedit_chains.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/gnome-screenshot/take_screenshot.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/indicator-applet/indicator_applet.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/indicator-applet/evolution_indicator.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/notify-osd/notify_osd.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/seahorse/generate_pgp.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/seahorse/generate_ssh.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/shotwell/shotwell_basics.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/simple_scan/simple_scan.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/ubuntu-menu/Accessories.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/ubuntu-menu/Games.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/ubuntu-menu/Internet.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/ubuntu-menu/Office.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/ubuntu-menu/SoundVideo.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/update-manager/update_manager.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/pidgin/pidgin_msn.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/pidgin/pidgin_new_account.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/pidgin/pidgin_notify.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/pidgin/pidgin_xmpp.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/evolution/evolution_indicator.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/evolution/evolution_messaging.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/evolution/evolution_notify.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/brasero/brasero_basics.html",
                        "http://reports.qa.ubuntu.com/reports/desktop-testing/natty/unity/latest/software_center/software_center.html"]

    for url in test_results_urls:
        page_exists = parse_entire_url(url, '</td><td class="result-fail"')
        if (page_exists == 404):
            color = RED
            number_of_tests = 0
        else:
            result = parse_entire_url(url,'class=')
            number_of_tests = len(result)
            failed_mago = parse_entire_url(url, '</td><td class="result-fail"')
            failed_mago = failed_mago + parse_entire_url(url, '</td><td class="result-error"')
            if (len(failed_mago) > 0):
                color = RED
            else:
                color = GREEN

        status = "Failed"
        count = 0
        if page_exists == 404:
            count = "All"
        else:
            for i in failed_mago:
#                status += i + " "
#                print status
                count += 1

        status = str(count) + " " + status
        test_name = url.split("/")[-1].split(".")[0]
        if page_exists == 404:
            status = test_name + ": " + "No Results Available"
        else:
            status = test_name + ": " + status + "/" + str(number_of_tests) + " Test(s)"

        data += "color=\"%s\" url=\"%s\" status=\"%s\"\n" % ("", url, status)
        rows += 1

    # Note: The name of the metric must not contain spaces
    data = "mago_automated_unity_tests: metric=\"%s\" rows=\"%d\" " % (metric, rows) + data
    create_file(MAGO_UNITY_TESTS_FILE, data)

mago_unity_tests()
