#!/usr/bin/python
# This script contains utility functions used in the QA Dashboar
# scripts.
# It is based on the ubuntu weatherreport from Leann Ogasawara.
#
# Copyright 2010-2011  Canonical, Ltd.
# Author: Marjo Mercado <marjo.mercado@canonical.com>
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
# the full text of the license.

import urllib2
import re
import os
from launchpadlib.launchpad import Launchpad
from launchpadlib.uris import LPNET_SERVICE_ROOT
from launchpadlib.credentials import Credentials

# Set up launchpad connection
cachedir = os.path.expanduser("~") + "/.cache/qadashboard"

# Look for pre-existing credentials and try to load those first
if os.path.exists(cachedir + "/credentials"):
    credentials = Credentials()
    credentials.load(open(cachedir + "/credentials"))
    launchpad = Launchpad(credentials, LPNET_SERVICE_ROOT, cachedir)
else:
    if not (os.path.exists(cachedir)):
        os.makedirs(cachedir)
    print "Be sure to authorize this script to 'Read Anything' in Launchpad."
    print ""
    launchpad = Launchpad.get_token_and_login('qadashboard',
                                              LPNET_SERVICE_ROOT, cachedir)
    launchpad.credentials.save(file(cachedir + "/credentials", "w"))

RED = "#ff7f8a"
GREEN = "#ccffcc"
GREY = "#d1cfcf"

DATA_DIR = os.path.expanduser("~") + "/qadashboard/data/"
RELEASE = "natty"
RELEASE_CAPS = RELEASE.title()
RELEASE_LONGNAME = "Ubuntu QA Dashboard"
MILESTONES_URL = "https://bugs.launchpad.net/ubuntu/" + RELEASE + "/+bugs?field.milestone%3Alist="
MILESTONES = [{"url": MILESTONES_URL + "27559",
               "name": RELEASE_CAPS + " Alpha1"},
              {"url": MILESTONES_URL + "27560",
               "name": RELEASE_CAPS + " Alpha2"},
              {"url": MILESTONES_URL + "27561",
               "name": RELEASE_CAPS + " Alpha3"},
              {"url": MILESTONES_URL + "27563",
               "name": RELEASE_CAPS + " Beta"},
              {"url": MILESTONES_URL + "27462",
               "name": RELEASE_CAPS + " 11.04"},
              {"url": MILESTONES_URL + "27564",
               "name": RELEASE_CAPS + " Updates"}]

FILES = ["bugs_most_users_affected.txt",
         "bugs_most_duplicates.txt",
         "boot_regressions.txt",
         "regression_tracker.txt",
         "packages_with_most_new_bugs_over_1.txt",
         "packages_with_most_new_bugs_over_7.txt",
         "hw_cert.txt",
         "iso_testing.txt",
         "automatic_upgrades.txt",
         "mago_tests.txt",
         "server_tests.txt",
         "desktop_tests.txt"]

BUGS_MOST_USERS_AFFECTED_FILE = DATA_DIR + "bugs_most_users_affected.txt"
BUGS_MOST_DUPLICATES_FILE = DATA_DIR + "bugs_most_duplicates.txt"
BOOT_REGRESSIONS_FILE = DATA_DIR + "boot_regressions.txt"
REGRESSION_TRACKER_FILE = DATA_DIR + "regression_tracker.txt"
HW_CERT_FILE = DATA_DIR + "hw_cert.txt"
ISO_TESTING_FILE = DATA_DIR + "iso_testing.txt"
AUTOMATIC_UPGRADES_FILE = DATA_DIR + "automatic_upgrades.txt"
MAGO_2D_TESTS_FILE = DATA_DIR + "mago_2d_tests.txt"
MAGO_TESTS_FILE = DATA_DIR + "mago_tests.txt"
MAGO_UNITY_TESTS_FILE = DATA_DIR + "mago_unity_tests.txt"
SERVER_TESTS_FILE = DATA_DIR + "server_tests.txt"
DESKTOP_TESTS_FILE = DATA_DIR + "desktop_tests.txt"

def parse_url(url, reg_exp):
    content = urllib2.urlopen(url).read()
    metric = re.search(reg_exp, content)
    if metric != None:
        return metric.group(1)
    return None

def parse_entire_url(url, reg_exp):
    try:
        content = urllib2.urlopen(url).read()
        metric = re.findall(reg_exp, content)
        return metric
    except urllib2.URLError, e:
        metric = e.code
        return metric

def append_file(file, data):
    FILE = open(file, 'a')
    FILE.write(str(data))
    FILE.close()

def create_file(file, data):
    FILE = open(file, 'w')
    FILE.write(str(data))
    FILE.close()
