#!/usr/bin/env python
# 
# 2008-11-17 
# Unflag the first attachment marked as a patch and
# add a comment informing people as to why their attachment
# is not a patch
#
# Example usage:
# uncheck-patch-comment.py 348960
#
# Copyright 2009 Canonical, Ltd
# Author: Brian Murray <brian@ubuntu.com>
# Licensed under the GNU General Public License, version 3.

import sys

import lpl_common


target = sys.argv[1]

launchpad = lpl_common.connect(version='devel')

bug = launchpad.bugs[target]

message_subject = "Re: %s" % bug.title

patch = 0

for attachment in bug.attachments:
    if attachment.type == "Patch":
        patch = 1
        attachment_title = attachment.title
        attachment.type = "Unspecified"
        attachment.lp_save()
        message = '''Looking at the attachments in this bug report, I noticed that "%s" was flagged as a patch.  A patch contains changes to an Ubuntu package that will resolve a bug, since this was not one I've unchecked the patch flag for it.  In the future keep in mind the definition of a patch.  You can learn more about what qualifies as a patch at https://wiki.ubuntu.com/Bugs/Patches.  Thanks!''' % attachment_title
        bug.newMessage(content=message, subject=message_subject)
        # remove the patch tag if the bug has it
        bug = launchpad.bugs[bug.id]
        if 'patch' in bug.tags:
            tag_list = bug.tags
            tag_list.remove('patch')
            bug.tags = tag_list
            bug.lp_save()
        print "updated LP: #%s" % bug.id
        break

if patch == 0:
    print "There are no patches attached to LP: #%s" % target
